Python module for converting markdown files to HTML. Forked from: https://github.com/AumitLeon/module_starter_cli

# Markdown to HTML Converter
[![CircleCI](https://circleci.com/gh/AumitLeon/markdown_html_converter.svg?style=svg)](https://circleci.com/gh/AumitLeon/markdown_html_converter) [![PyPI version](https://badge.fury.io/py/md-to-html.svg)](https://badge.fury.io/py/md-to-html)
[![semantic-release](https://img.shields.io/badge/%20%20%F0%9F%93%A6%F0%9F%9A%80-semantic--release-e10079.svg)](https://github.com/semantic-release/semantic-release)
[![PyPI license](https://img.shields.io/pypi/l/ansicolortags.svg)](https://pypi.python.org/pypi/ansicolortags/)
[![Documentation Status](https://readthedocs.org/projects/markdown-html-converter/badge/?version=latest)](https://markdown-html-converter.readthedocs.io/en/latest/?badge=latest)


The purpose of this project is to create a simple to use python module that can convert markdown files into rich HTML.

## Table of Contents
<!-- TOC depthFrom:2 -->
- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
<!-- /TOC -->

This project is preconfigured with [CircleCi](https://circleci.com/) for continuous integration and delivery; releases are automated via `semantic-release.`

## Installation
To install this module:
```
pip install md-to-html
```

## Usage
This module's usage is summarized below:
```
usage: md-to-html [-h] --input INPUT [--output OUTPUT]

Convert Markdown File to HTML file

optional arguments:
  -h, --help show this help message and exit
  --input INPUT, -i INPUT input markdown file
  --output OUTPUT, -o OUTPUT output HTML file
```

## Contributing
If you find this project useful and would like to contribute back to it, feel free to check out the [`CONTRIBUTING`](CONTRIBUTING.md) page. 
